#
# spec file for package python-slack-sdk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
Name:           python-slack-sdk
Version:        3.19.5
Release:        1.1
Summary:        Python SDKs for the Slack API
License:        MIT
URL:            https://github.com/slackapi/python-slack-sdk
Source:         https://github.com/slackapi/python-slack-sdk/archive/v%{version}.tar.gz#/slack-sdk-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Obsoletes:      python-slackclient < %{version}
Provides:       python-slackclient = %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module itsdangerous}
BuildRequires:  %{python_module moto}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sqlalchemy}
BuildRequires:  %{python_module websockets}
# /SECTION
%python_subpackages

%description
The Slack platform offers several APIs to build apps. Each Slack API delivers
part of the capabilities from the platform, so that you can pick just those
that fit for your needs. This SDK offers a corresponding package for each of
Slack’s APIs. They are small and powerful when used independently, and work
seamlessly when used together, too.

%prep
%setup -q -n python-slack-sdk-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# No flask_sockets in Tumbleweed; TestRTMClient requires network
%pytest --ignore-glob '*/socket_mode/*' -k 'not TestRTMClient' tests

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Jan  6 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Change log is upto date with the version.
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.19.5
  [#1303] Fix #1302 by updating the warning logs in WebClient to be consistent with Node SDK - Thanks @mar3mar3
  [#1307] Fix #1304 ssl_context is not passed from async web_client to aiohttp socket client - Thanks @seratch @giwrgos-skouras
  [#1308] Fix #1305 by fixing pagination with async for syntax - Thanks @seratch @WilliamYuhangLee
- Update to v3.19.4
  [#1301] Fix #1297 Building user_auth_blocks with slack_sdk.models class objects for chat.unfurl API call fails - Thanks @seratch @injust
- Update to v3.19.3
  [#1288] Add datetimepicker, url, email, number block elements - Thanks @WilliamBergamin
  [#1294] Fix #1292 files_upload_v2 does not work with io.BytesIO file parameters - Thanks @seratch
  [#1290] Update RTM API documents - Thanks @ryan-aldaz
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.19.2
  [#1282] Add request_file_info arg to files_upload_v2 method - Thanks @seratch @eddyg
  [#1278] Improve clarity of 'content' error message for files_upload_v2 - Thanks @eddyg
  [#1283] Improve typing when using 'get' on an API response - Thanks @eddyg
  [#1284] Add Python 3.11 support - Thanks @seratch
  [#1281] Fix selected_option type hint - Thanks @taekop
  All issues/pull requests: https://github.com/slackapi/python-slack-sdk/milestone/71?closed=1
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.19.1
  Improve WebClient#files_upload_v2() to use given filename as the default title value - Thanks @seratch @mattpr
- Update to 3.19.0
  [#1272] Add files.upload v2 support, which resolves #1191 #1165 - Thanks @seratch
- Update to 3.18.5
  [#1271] Add more revert to #1269 - Thanks @seratch @yardensachs
- Update to 3.18.4
  [#1264] Fix retry_handlers type hint in AsyncBaseClient - Thanks @ronyb29
  [#1265] #1266 Add selected_time (timepicker) to ViewStateValue class - Thanks @rei-0
  [#1270] Add include_all_metadata to conversations.replies API arguments - Thanks @seratch
  [#1269] Adjust the logic added by #1246 - Thanks @seratch @eddyg
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.18.3
  Changes
  * #1262 Fix #1261 blocks/attachments as str for chat. API calls should be clearly supported - Thanks @seratch
  * #1259 Fix #1258 Tuple value for blocks argument does not work for Web API calls - Thanks @tommasobertoni
  * #1253 Minor update: max elements in ActionsBlock to 25 - Thanks @YSaxon
  * #1249 #1251 Add in timezone property for timepicker element - Thanks @hello-ashleyintech
* Wed Aug  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Inital release, 3.18.1
